.. -*- mode: rst -*-

|Travis|_ |AppVeyor|_ |Codecov|_ |CircleCI|_ |ReadTheDocs|_

.. |Travis| image:: https://travis-ci.org/scikit-learn-contrib/project-template.svg?branch=master
.. _Travis: https://travis-ci.org/scikit-learn-contrib/project-template

.. |AppVeyor| image:: https://ci.appveyor.com/api/projects/status/coy2qqaqr1rnnt5y/branch/master?svg=true
.. _AppVeyor: https://ci.appveyor.com/project/glemaitre/project-template

.. |Codecov| image:: https://codecov.io/gh/scikit-learn-contrib/project-template/branch/master/graph/badge.svg
.. _Codecov: https://codecov.io/gh/scikit-learn-contrib/project-template

.. |CircleCI| image:: https://circleci.com/gh/scikit-learn-contrib/project-template.svg?style=shield&circle-token=:circle-token
.. _CircleCI: https://circleci.com/gh/scikit-learn-contrib/project-template/tree/master

.. |ReadTheDocs| image:: https://readthedocs.org/projects/sklearn-rvm/badge/?version=latest
.. _ReadTheDocs: https://sklearn-rvm.readthedocs.io/en/latest/?badge=latest

Sklearn-RVM
===========


Installation
------------

.. code:: bash

    pip install sklearn-rvm


Requirements
------------
.. _Scikit-Learn: https://scikit-learn.org/

- Python (>= 3.5)
- Scikit-Learn_ (>= 0.21)

Documentation
-------------

.. _documentation: https://sklearn-rvm.readthedocs.io/en/latest/quick_start.html

Refer to the documentation_ to modify the template for your own scikit-learn
contribution.